@@ -1,11 +1,11 @@
 use arrow::{error::ArrowError, ipc::writer::FileWriter, json::ReaderBuilder};
-use clap::{Clap, ValueHint};
+use clap::{Parser, ValueHint};
 use serde_json::to_string_pretty;
 use std::io::stdout;
 use std::path::PathBuf;
 use std::{fs::File, io::Write};
 
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(version = env!("CARGO_PKG_VERSION"), author = "Dominik Moritz <domoritz@cmu.edu>")]
 struct Opts {
     /// Input JSON file.
@@ -16,7 +16,7 @@ struct Opts {
     #[clap(name = "ARROW", parse(from_os_str), value_hint = ValueHint::AnyPath)]
     output: Option<PathBuf>,
 
-    /// The number of records to infer the schema from. All rows if not present.
+    /// The number of records to infer the schema from. All rows if not present. Setting max-read-records to zero will stop schema inference and all columns will be string typed.
     #[clap(short, long)]
     max_read_records: Option<usize>,
 
